@@ -5,7 +5,10 @@
 #' @param stats.mode Select subset of standard stats. One of: c("all", "checkable", "computable", "uncomputable").
 #' @param recalculate.p Logical. If TRUE recalculates p values (for 2 sided test) if possible.
 #' @param alternative Character. Select test sidedness for recomputation of p-values from t-, r- and beta-values. One of c("undirected", "directed"). If "directed" is specified, p-values for directed null-hypothesis are added to the table but still require a manual inspection on consistency of the direction.
-#' @param estimateZ Logical. If TRUE detected beta-/d-value is divided by reported standard error "SE" to estimate Z-value ("Zest") for observed beta/d and recompute p-value. Note: This is only valid, if Gauss-Marcov assumptions are met and a sufficiently large sample size is used. If a Z- or t-value is detected in a report of a beta-/d-coefficient with SE, no estimation will be performed, although set to TRUE.
+#' @param checkP Logical. If TRUE observed and recalculated p-values are checked for consistency.
+#' @param alpha Numeric. Defines the alpha level to be used for error assignment.
+#' @param criticalDif Numeric. Sets the absolute maximum difference in reported and recalculated p-values for error detection.
+#' @param estimateZ Logical. If TRUE detected beta-/d-values are divided by the reported standard error "SE" to estimate Z-values ("Zest") for observed beta/d and computation of p-values. Further, t-values that are reported without degrees of freedom will be treated as an estimate for Z. Note: This is only valid, if Gauss-Marcov assumptions are met and a sufficiently large sample size is used. If a Z- or t-value with degrees of freedom is detected in a report of a beta-/d-coefficient with SE, no estimation of Z will be performed, although set to TRUE.
 #' @param T2t Logical. If TRUE capital letter T is treated as t-statistic.
 #' @param R2r Logical. If TRUE capital letter R is treated as correlation.
 #' @param select Select specific standard statistics only (e.g.: c("t", "F", "Chi2")).
@@ -25,17 +28,35 @@
 #' BF(01)>4","chi=3.2, r(34)=-.7, p<.01, R2=76%.")
 #' standardStats(x)
 
-standardStats<-function(x,stats.mode="all",recalculate.p=TRUE,alternative="undirected",estimateZ=FALSE,T2t=FALSE,R2r=FALSE,select=NULL,rm.na.col=TRUE,warnings=TRUE){
+standardStats<-function(x,stats.mode="all",
+                        recalculate.p=TRUE,
+                        alternative="undirected",
+                        checkP=FALSE,
+                        alpha=.05,
+                        criticalDif=.02,
+                        estimateZ=FALSE,
+                        T2t=FALSE,R2r=FALSE,
+                        select=NULL,
+                        rm.na.col=TRUE,
+                        warnings=TRUE){
 # set warning massages to FALSE
-warn.T2t<-FALSE;warn.R2r<-FALSE;warn.r<-FALSE;warn.R2<-FALSE;warn.p<-FALSE;warn.d<-FALSE;warn.eta<-FALSE;warn.multi.p<-FALSE
-   x<-unlist(x)
+warn.T2t<-FALSE;warn.R2r<-FALSE;warn.r<-FALSE;warn.R2<-FALSE;warn.p<-FALSE;warn.d<-FALSE;warn.eta<-FALSE;warn.multi.p<-FALSE;warn.Zest<-FALSE; warn.ZestT<-FALSE 
+Zest<-FALSE;ZestT<-FALSE
+x<-unlist(x)
 # convert with all.stats() if has " [<=>] [0-9\\.-]"
 if(length(grep(" [<=>] [0-9\\.-]|[<=>] [0-9\\.-]",x))>0) x<-allStats(x)
+# get lines with operator-number
+x<-grep("[<=>]-*[\\.0-9]",x,value=TRUE)
+# escape
+if(length(x)==0) return(NULL)
+
 if(length(x)>0){
-# convert 10-num to 10^-num
-x<-gsub("([^0-9]10)(-[1-9]*)$","\\1^\\2",x)  
 # take copy for raw output
 y<-x
+# remove page number
+x<-gsub("[ \\(]p\\. [1-9][0-9]*","",x)  
+# convert 10-num to 10^-num
+x<-gsub("([^0-9]10)(-[1-9][0-9]*)","\\1^\\2",x)  
 # remove space between letter and (
 x<-gsub("([A-Za-z]) (\\([0-9Nnd])","\\1\\2",x)
 
@@ -43,10 +64,18 @@ x<-gsub("([A-Za-z]) (\\([0-9Nnd])","\\1\\2",x)
 x<-gsub("([0-9]) [Ee] *([+-][0-9])","\\1e\\2",x)
 x<-gsub("([0-9]) [Ee]([0-9])","\\1e+\\2",x)
 
+# remove 'Total' 
+x<-gsub("Total[a-z]*| total[a-z]*","",x)
+
 # remove 'Letter'chi'letter' 
 x<-gsub("[A-Za-z]chi[a-z]","",x)
 x<-gsub("[A-Za-z]chi[a-z]","",x)
 
+# remove stars behind number
+x<-gsub("([0-9])\\^*\\*\\**([^\\*0-9\\.])","\\1\\2",x)
+# remove superscripted text behind number
+x<-gsub("([0-9])\\^[A-z[:punct:]][A-z0-9]*","\\1",x)
+
 # capital T to small t
    if(T2t==TRUE){
      # need warning for T2t?
@@ -68,6 +97,10 @@ x<-gsub(" d *[a-eg-zA-EG-Z0-9]([^a-zA-Z0-9])|^d *[a-eg-zA-EG-Z0-9]([^a-zA-Z0-9])
 x<-gsub("chi2*/[a-z0-9]*[<=>]*[0-9\\.]*","",x)
 # remove chi2/df=num
 x<-gsub("chi[\\^]*2* */ *df=[0-9]*\\.[0-9]","",x)
+# remove delta chi2=num
+x<-gsub("delta chi[\\^]*2* *=-*[0-9]*\\.[0-9]","",x)
+# remove delta anything=num
+x<-gsub("delta [A-z][A-z]*[\\^2]*[<=>][<=>]*-*[0-9\\.][0-9\\.]*","",x)
 
  # remove percent value in brackets
    x<-gsub(" \\([0-9\\.]*\\%\\)","",x)     
@@ -115,7 +148,11 @@ x<-unlist(lapply(x,percent2number))
    # remove ^ from "letter^2"
    x<-gsub("([a-zA-Z])[\\^]2","\\12",x)
    # unify p-value
-   x<-gsub("([^a-z])p[- ]value","\\1p",x)
+   x<-gsub("([^a-z])p[- ][vV]alue","\\1p",x)
+   # remove "value"
+   x<-gsub("[- ][vV]alues*"," ",x)
+   # remove "statistics*"
+   x<-gsub("[- ][Ss]tatisti[ck]s*"," ",x)
    # remove " all"
    x<-gsub("all ","",x)
    x<-gsub("-","-",x)
@@ -151,6 +188,7 @@ x<-unlist(lapply(x,percent2number))
    x<-gsub("\u00DF","beta",x) # sharp s
    x<-gsub("\u0392","beta",x) # greek capital BETA
    x<-gsub("[Bb]etas","beta",x) # singular
+   x<-gsub(" [B]([<=>])"," beta\\1",x) # singular
    # unify chi2s -> chi2
    x<-gsub("X2|[Cc]hi2s|X 2 ","Chi2",x) 
    x<-gsub("[Cc]hi[- ][Ss]quare|[Cc]hisquare","Chi2",x) 
@@ -175,7 +213,8 @@ x<-unlist(lapply(x,percent2number))
    x<-gsub("eta G|eta\\([gG]\\)","eta",x)
    x<-gsub("eta2|eta2 G|eta2\\([gG]\\)","eta2",x)
    # unify SE
-   x<-gsub("[sS]\\.[eE]\\.","SE",x)
+   x<-gsub(" [sS]\\.[eE]\\.","SE",x)
+   x<-gsub("^[sS]\\.[eE]\\.","SE",x)
    # plural to singular
    x<-gsub("([^a-z][tFrpZd])s([^a-z])","\\1\\2",x)
    x<-gsub("^([tFrpZd])s([^a-z])","\\1\\2",x)
@@ -282,7 +321,7 @@ x<-unlist(strsplit2(x,"[^-\\.0-9][-\\.0-9]*?\\^[-\\.0-9]","before"))
                                        as.numeric(gsub("[^-0-9\\.].*","\\1",gsub(".*[-0-9\\.]*?\\^([-\\.0-9]*)","\\1",x[ind])))),
                                  scientific=F))
 
-        # clean up white spaces
+    # clean up white spaces
     res<-gsub("^ *|(?<= ) | *$", "", res, perl = TRUE)
     # remove only zeros at end
     res<-gsub("\\.[0]*$","",res)
@@ -320,12 +359,20 @@ x<-gsub("([<=>]) ","\\1",x)
 # remove spaces in operator-space-num 
 x<-gsub("([<=>]-) ([\\.0-9])","\\1\\2",x)
 
+# remove first of two beta values followed by SE
+x<-gsub(" [bB]=[-\\.0-9]*, ([bB]=[-\\.0-9]*.* SE=[-\\.0-9]*),"," \\1",x)
+x<-gsub(" [bB]=[-\\.0-9]*, ([bB]eta=[-\\.0-9]*.* SE=[-\\.0-9]*),"," \\1",x)
+x<-gsub(" [bB]eta=[-\\.0-9]*, ([bB]=[-\\.0-9]*.* SE=[-\\.0-9]*),"," \\1",x)
+x<-gsub(" [bB]eta=[-\\.0-9]*, ([bB]eta=[-\\.0-9]*.* SE=[-\\.0-9]*),"," \\1",x)
+
+
 # prepare results colnames
-cnames<-c("result","Z_op","Z","F_op","F","eta2","omega2","t_op","t","d","SE","r_op","r","R2_op","R2","U_op","U","H_op","H","G2_op","G2","OR","RR","Chi2","Q_op","Q","df1","df2","beta","SEbeta","Zest","BF10_op","BF10","BF_op","BF","p_op","p","recalculatedP","p_H1_less","p_H1_greater")
+cnames<-c("result","beta","SEbeta","t_op","t","d","SE","Z_op","Z","Zest","F_op","F","eta2","omega2","r_op","r","R2_op","R2","U_op","U","H_op","H","G2_op","G2","OR","RR","Chi2","Q_op","Q","df1","df2","BF10_op","BF10","BF_op","BF",
+          "p_op","p","codedP_op","codedP","recalculatedP","p_H1_less","p_H1_greater")
 res<-matrix(NA,nrow=length(x),ncol=length(cnames))
 colnames(res)<-cnames
 
-## extract beta and d and standarderror than calculate Zest
+## extract beta and d and standard error than calculate Zest
 # unify
 x<-gsub("[Ss]lope|[Bb]eta"," b",x)
 x<-gsub(" [Ss][Ee]\\([a-zA-Z]*)"," SE",x)
@@ -337,17 +384,36 @@ x<-gsub("  "," ",x)
 x<-gsub("Cohen.s d.*?([<=>])","d\\1",x)
 x<-gsub("Cohens d.*?([<=>])","d\\1",x)
 
+# if has codedP extract
+if(length(grep(";; p[<=>]",x))>0){
+   index<-grep(";; p[<=>]",x)
+   # extract
+   codedP<-suppressWarnings(as.numeric(gsub(".*;; p *[<=>][<=>]* *([0\\.]*[0-9][0-9]*).*","\\1",x[index])))
+   codedP_op<-gsub(".*;; p *([<=>][<=>]*) *[0\\.]*[0-9][0-9]*.*","\\1",x[index])
+   # add to res
+   res[index,"codedP"]<-codedP
+   res[index,"codedP_op"]<-codedP_op
+   res[index,"result"]<-y[index]
+   
+   # remove codedP from x for further processing
+   x[index]<-gsub(";; p *[<=>][<=>]* *[0\\.]*[0-9][0-9]*","",x[index])
+}
+
+
 # if has beta extract beta and SE beta
 if(length(grep("^b[<=>]| b[<=>]",x))>0){
    index<-grep("^b[<=>]| b[<=>]",x)
    # extract
-   beta<-suppressWarnings(as.numeric(gsub("[,; ].*","",unlist(lapply(strsplit(x[index]," b[<=>]*|^b[<=>]*"),"[",2)))))
-   SE<-suppressWarnings(as.numeric(gsub("[,; ].*","",gsub(".* SE[<=>]*","",x[index]))))
+   beta<-suppressWarnings(as.numeric(gsub("[,; ].*","",unlist(lapply(strsplit(x[index]," b[<=>]|^b[<=>]"),"[",2)))))
+   SE<-suppressWarnings(as.numeric(gsub("[,; ].*","",gsub(".* SE[<=>][<=>]*|^SE[<=>][<=>]*","",x[index]))))
    # add to res
    res[index,"beta"]<-beta
    res[index,"SEbeta"]<-SE
    res[index,"result"]<-y[index]
+   temp<-res
    if(estimateZ==TRUE) res[index,"Zest"]<-beta/SE
+   if(!identical(temp,res)) Zest<-TRUE
+   
 }
 
 ## get d value
@@ -371,14 +437,18 @@ if(length(grep("^d[<=>]| d[<=>]",x))>0&length(grep(" SE[<=>]|^t\\([0-9]| t\\([0-
    res[index,"d"]<-d
    res[index,"SE"]<-SE
    res[index,"result"]<-y[index]
+   temp<-res
    if(estimateZ==TRUE) res[index,"Zest"]<-d/SE
+   if(!identical(temp,res)) Zest<-TRUE
+   
 }
 
 ## if has SE but no beta or d extract SE
-if(length(grep(" SE[<=>]",x))>0&length(grep("^b[<=>]| b[<=>]",x))==0&length(grep("^d[<=>]| d[<=>]",x))==0){
-   index<-grep(" SE[<=>]",x)
+if(length(grep(" SE[<=>]|^SE[<=>]",x))>0&length(grep("^b[<=>]| b[<=>]",x))==0&length(grep("^d[<=>]| d[<=>]",x))==0){
+   index<-grep(" SE[<=>]|^SE[<=>]",x)
+   
    # extract
-   SE<-suppressWarnings(as.numeric(gsub("[,; ].*","",gsub(".* SE[<=>]*","",x[index]))))
+   SE<-suppressWarnings(as.numeric(gsub("[,; ].*","",gsub(".* SE[<=>][<=>]*|^SE[<=>][<=>]*","",x[index]))))
    # add to res
    res[index,"SE"]<-SE
    res[index,"result"]<-y[index]
@@ -395,29 +465,41 @@ x<-gsub("( )t[a-zA-Z]\\(([1-9])|^t[a-zA-Z]\\(([1-9])","\\1t(\\2\\3",x)
 index<-grep(" t[<>=]|^t[<>=]| t[(][\\.0-9 df=]*[)]|^t[(][\\.0-9 df=]*[)]",x)
 if(length(index>0)){
   tval<-x[index]
-# remove till first t value if has 2
+  # take a copy
+  tval2<-tval
+  # remove till first t value if has 2
   ft<-function(x){lapply(strsplit2(tval,"^t[<>=(]| t[<>=(]","before"),function(x) grep("^t[<>=(]| t[<>=(]",x,value=TRUE)[1])}
   tval<-unlist(ft(tval))
   tval<-gsub(".* t([(<>=])","t\\1",tval)
-  # remove'df='
+  # remove "df=" from "(df="
   tval<-gsub("\\(df=([1-9])","(\\1",tval)
-  # df
+  # extract df
   tdf<-rep(NA,length(tval))
-  # index for lines with df
+  # index for lines with t(df)
   ind<-grep(" t[(]|^t[(]",tval)
   if(length(ind)>0) tdf[ind]<-gsub("[,;].*","",gsub("[)].*","",gsub(".*t[(]","",tval[ind])))
-  ind<-grep(" df=",tval)
-  if(length(ind)>0) tdf[ind]<-gsub(",;.*","",gsub("[^0-9\\.].*","",gsub(".* df=","",tval[ind])))
+  # index for lines with df= and no t(df)
+  ind<-which(is.element(grep(" df2*=",tval2),grep(" t\\([1-9]|^t\\([1-9]",tval,invert=TRUE)))
+  if(length(ind)>0) tdf[ind]<-gsub(",;.*","",gsub("[^0-9\\.].*","",gsub(".* df2*=","",tval2[ind])))
   # get sign
   sign<-gsub("[^<>=].*","",sub("[^<>=]*([=<>])", "\\1",sub(".* t([\\(=<>])","\\1",tval)))
   # clean up t value
   tval<-gsub("\\([0-9\\.,;]*\\)|\\]","",tval) # remove df within brackets
   tval<-suppressWarnings(as.numeric(gsub(".*[=<>]","",gsub("[;,] .*| .*|[;,]$","",gsub(".*t[(<>=]|^t[(<>=]","",tval)))))
+  
   # insert results to res
   res[index,c("t_op","t","df2")]<-cbind(sign,tval,tdf)
   res[index,"result"]<-y[index]
 }
 
+# convert t to Zest if t-value but no df is detected and Zest wasn't computed before
+if(estimateZ==TRUE){ 
+   temp<-res
+   index<-!is.na(res[,"t"])&is.na(res[,"df2"])&is.na(res[,"Zest"])
+   res[index,"Zest"]<-res[index,"t"]
+   if(!identical(temp,res)) ZestT<-TRUE
+   
+}   
 
 ## get F-value and its df1 and df2
 # remove number of numbered F-values
@@ -442,7 +524,7 @@ res[ind,"result"]<-x[ind]
 }
 
 # extract omega2 
-ind<-grep(" omega[2<=>]|^omega[2<>=]",x)
+ind<-grep(" omega\\^*2[<=>]|^omega\\^*2[<>=]",x)
 if(length(ind)>0){
 omega<-rep(NA,length(ind))
  omega<-gsub("[^0-9\\.].*","",gsub(".*[<=>]","",gsub("[,;] .*| [a-zA-Z].*","",unlist(lapply(strsplit(x[ind]," omega|^omega"),"[",2)))))
@@ -481,11 +563,11 @@ Fval<-suppressWarnings(as.numeric(Fval))
 # don't overwrite dfs (here copy value if not NA)
 if(length(index)==1){
 df2[which(!is.na(res[index,"df2"]))]<-res[index,"df2"][!is.na(res[index,"df2"])]
-df1[which(!is.na(res[index,"df2"]))]<-res[index,"df1"][!is.na(res[index,"df2"])]
+df1[which(!is.na(res[index,"df1"]))]<-res[index,"df1"][!is.na(res[index,"df1"])]
 }
 if(length(index)>1){
 df2[which(!is.na(res[index,"df2"]))]<-res[index,][!is.na(res[index,"df2"]),"df2"]
-df1[which(!is.na(res[index,"df2"]))]<-res[index,][!is.na(res[index,"df2"]),"df1"]
+df1[which(!is.na(res[index,"df1"]))]<-res[index,][!is.na(res[index,"df1"]),"df1"]
 }
 
 
@@ -545,6 +627,10 @@ if(length(grep("^chi[A-Za-z]| chi[A-Za-z]",x))>0) x[grep("^chi[A-Za-z]| chi[A-Za
 index<-grep(" chi[<=>(]|^chi[<=>(]",x)
 if(length(index)>0){
 chi2<-x[index]
+# remove beginning from second occurance
+chi2<-gsub("(.*chi[<=>(].*) chi[<=>(].*","\\1",chi2)
+chi2<-gsub("(.*chi[<=>(].*) chi[<=>(].*","\\1",chi2)
+
 chidf<-rep(NA,length(chi2))
 # find df by coding chi(df)
 ind<-grep("chi[(]",chi2)
@@ -618,7 +704,7 @@ res[index,"df2"][use]<-rdf[use]
 }
 
 ## extract H
-index<-grep("[\\( ]H[<=>]|^H[<=>]|[\\( ]H \\([0-9]|^H \\([1-9]|[\\( ]H\\([0-9]|^H\\([1-9]",x)
+index<-grep("[\\( ]H[<=>]|^H[<=>]|[\\( ]H *\\([1-9][0-9]*\\) *[<=>]|^H *\\([1-9][0-9]*\\) *[<=>]",x)
 if(length(index)>0){
 H<-x[index]
 H<-gsub(", [Nn]=[0-9]*","",H)
@@ -684,7 +770,7 @@ res[index,"df1"][use]<-G2df[use]
 
 
 ## extracts only R2 no type yet
-index<-grep("^[Rr]2[(<= ]|[^A-Za-z][Rr]2[(<= ]|[Rr] 2[(<= ]|[^A-Za-z][Rr] 2[(<= ]",x)
+index<-grep("^[Rr] *2 *[(<= ]|[^A-Za-z][Rr] *2 *[(<= ]",x)
 if(length(index)>0){
 R2<-x[index]
 # unify
@@ -934,6 +1020,7 @@ res[index,c("df1")][i2]<-cbind(Qdf)[i2]
 }
 
 
+
 ############
 ## clean up
 ##########
@@ -999,6 +1086,9 @@ if(sum(rowSums(!is.na(d))>1)>0) warn.multi.p<-TRUE
 # get p value by rank t, F, r, chi, Z, H, G2, Q
 recalculatedP<-NULL
 for(i in 1:dim(d)[1]) recalculatedP[i]<-d[i,][!is.na(d[i,])][1]
+# round recalculatedP and deltaP2tailed
+recalculatedP<-round(recalculatedP,4)
+
 # add to res
   if(!is.null(dim(res))) res[,"recalculatedP"]<-recalculatedP
   if(is.null(dim(res))) res["recalculatedP"]<-recalculatedP
@@ -1096,6 +1186,9 @@ if(sum(as.numeric(res[,"p"])>1|as.numeric(res[,"p"])<0,na.rm=T)>0) warn.p=TRUE
 if(sum(as.numeric(abs(as.numeric(res[,"d"])))>1,na.rm=T)>0) warn.d<-TRUE   
 # need warning massage for eta^2 > .3
 if(sum(as.numeric(abs(as.numeric(res[,"eta2"])))>.3,na.rm=T)>0) warn.eta<-TRUE   
+# need warning massage Zest
+if(Zest & sum(as.numeric(abs(as.numeric(res[,"Zest"])))>0,na.rm=T)>0) warn.Zest<-TRUE   
+if(ZestT & sum(as.numeric(abs(as.numeric(res[,"Zest"])))>0,na.rm=T)>0) warn.ZestT<-TRUE   
 
 ## remove columns with only NA if something is left
 if(!is.null(dim(res))){
@@ -1133,13 +1226,14 @@ names(res)<-n
 } # end remove columns
 
 # set empty result to character(0)
-if(is.null(res)) res<-character(0)
+if(is.null(res)) res<-NULL
 
-if(!is.null(ncol(res))) if(ncol(res)==0) res<-character(0)
-if(!is.null(ncol(res))) if(nrow(res)==0) res<-character(0)
+if(!is.null(ncol(res))) if(ncol(res)==0) res<-NULL
+if(!is.null(ncol(res))) if(nrow(res)==0) res<-NULL
 
-}else res<-character(0)
-}else res<-character(0) # end escape
+}else res<-NULL
+}else res<-NULL
+# end escape
 
 ## Warning massages
    report<-NULL
@@ -1151,8 +1245,10 @@ if(warn.p==TRUE) report<-c(report,"- One or more detected p-values are out of ra
 if(warn.d==TRUE) report<-c(report,"- A rather big effect was detected. One or more |d|-values > 1.\n")
 if(warn.eta==TRUE) report<-c(report,"- A rather big effect was detected. One or more eta^2-values > .3.\n")
 if(warn.multi.p==TRUE) report<-c(report,"- There are one or more results with several recomputable test statistics. Please split the result manually and proceed checking.\n")
-
-if(warnings==TRUE&!is.null(report)) warning(report)
+if(warn.Zest==TRUE) report<-c(report,"- Z-value estimation was performed by beta/SE, d/SE to recalculate p-values. This estimation is biased in small samples and may be the cause for deviations to the reported p-values.\n")
+if(warn.ZestT==TRUE) report<-c(report,"- Reported t-values with no degrees of freedom were treated as Z-values to recalculate p-values. This estimation is biased in small samples and may be the cause for deviations to the reported p-values.")
+   
+if(warnings==TRUE&!is.null(report)) warning(report,call.=FALSE)
    
    # prepare output
    stats<-res
@@ -1162,7 +1258,12 @@ if(dim(stats)[1]>0){
 if(length(grep("_op|result",names(stats),invert=TRUE))>0){
   for(i in grep("_op|result",names(stats),invert=TRUE)) stats[,i]<-as.numeric(stats[,i],warn=F)
 }
-}else stats<-character(0)
+}else stats<-NULL
+
+if(checkP==TRUE) stats<-pCheck(stats,alpha=alpha,criticalDif=criticalDif,warnings=warnings)
+
+# insert copy of input to column result
+
 return(stats)
 
 }
